/*global Drupal, jQuery*/
Drupal.behaviors.euccRocketship = {
  attach: function (context, settings) {
    (function ($) {

      // Init when the popup has opened
      var dynamicButtonChanged = false;
      var body = $('body');
      body.once('euccRocketshipOpen').on('eu_cookie_compliance_popup_open', function() {
        $('.eu-cookie-compliance-banner-info').once('euccRocketship').each(function () {
          initCloseEvent();
          initStateLabel();
          initDynamicButton();
          initAcceptMinimal();
        });
        if (typeof settings.eu_cookie_compliance_rocketship__excluded_path == 'undefined' || !settings.eu_cookie_compliance_rocketship__excluded_path) {
          body.addClass('eucc-popup-showing');
        }
      });
      body.once('euccRocketshipClose').on('eu_cookie_compliance_rocketship__popup_close', function() {
        body.removeClass('eucc-popup-showing');
      });
      body.once('euccRocketshipOpenExcluded').on('eu_cookie_compliance_rocketship__show_excluded', function() {
        body.addClass('eucc-popup-showing');
      });

      /**
       * Helper function to trigger an event when the popup is closed
       */
      function initCloseEvent() {
        var buttons = $('.eu-cookie-compliance-banner-info button');
        buttons.once('euccRocketshipCloseEvent').click(function (e) {
          $(this).trigger('eu_cookie_compliance_rocketship__popup_close')
        });
      }

      /**
       * Helper function to initialize the state label functionality
       */
      function initStateLabel() {
        var categories = $('.eu-cookie-compliance-category');
        categories.each(function () {
          var category = $(this);
          var check = category.find('input[type="checkbox"]');
          var stateLabel = category.find('.state-label');
          check.change(function () {
            if (check.prop('checked')) {
              stateLabel.addClass('visible');
            }
            else {
              stateLabel.removeClass('visible');
            }
          });
        });
      }

      /**
       * Helper function to initialize the dynamic button
       */
      function initDynamicButton() {
        var dynamicButton = $('.eu-cookie-compliance-rocketship--dynamic-accept');
        updateDynamicButtonText(dynamicButton, true);
        var categoryChecks = $('.eu-cookie-compliance-category input[type="checkbox"]');
        categoryChecks.change(function() {
          updateDynamicButtonText(dynamicButton, false);
        });

        dynamicButton.click(function (e) {
          e.preventDefault();
          if (dynamicButton.hasClass('all')) {
            $('.agree-button.eu-cookie-compliance-default-button').click();
          }
          else {
            $('.eu-cookie-compliance-save-preferences-button').click();
          }
        });
      }

      /**
       * Helper function to update the dynamic button text
       */
      function updateDynamicButtonText(dynamicButton, useSaved) {
        var savedCategories = Drupal.eu_cookie_compliance.getAcceptedCategories();
        var selectedCategories = $('.eu-cookie-compliance-category:not(.disabled) input[type="checkbox"]:checked');
        if (selectedCategories.length || (useSaved && savedCategories.length)) {
          dynamicButton.html(dynamicButton.attr('data-selection'));
          dynamicButton.removeClass('all');
          dynamicButton.addClass('selected');
          dynamicButtonChanged = true;
        }
        else {
          if (!dynamicButtonChanged) {
            dynamicButton.html(dynamicButton.attr('data-all'));
            dynamicButton.removeClass('selected');
            dynamicButton.addClass('all');
          }
        }
      }

      /**
       * Helper function to initialize the accept minimal link
       */
      function initAcceptMinimal() {
        var acceptMinimalLink = $('.eu-cookie-compliance-rocketship--accept-minimal');
        var categoryChecks = $('.eu-cookie-compliance-category:not(.disabled) input[type="checkbox"]');
        acceptMinimalLink.click(function (e) {
          e.preventDefault();
          categoryChecks.prop('checked', false);
          $('.eu-cookie-compliance-save-preferences-button').click();
        });
      }

    }(jQuery));
  }
};
